@@ -88,9 +88,18 @@ EXPRESSION_METADATA: ExpressionMetadataType = {
     **{
         expr_type: {"returns": exp.DataType.Type.DOUBLE}
         for expr_type in {
+            exp.Asin,
+            exp.Asinh,
+            exp.Acos,
+            exp.Acosh,
             exp.ApproxQuantile,
+            exp.Atan,
+            exp.Atanh,
             exp.Avg,
             exp.Cbrt,
+            exp.Cos,
+            exp.Cosh,
+            exp.Cot,
             exp.Exp,
             exp.Kurtosis,
             exp.Ln,
@@ -101,10 +110,14 @@ EXPRESSION_METADATA: ExpressionMetadataType = {
             exp.Radians,
             exp.Round,
             exp.SafeDivide,
+            exp.Sin,
+            exp.Sinh,
             exp.Sqrt,
             exp.Stddev,
             exp.StddevPop,
             exp.StddevSamp,
+            exp.Tan,
+            exp.Tanh,
             exp.ToDouble,
             exp.Variance,
             exp.VariancePop,
@@ -119,6 +132,7 @@ EXPRESSION_METADATA: ExpressionMetadataType = {
             exp.Ceil,
             exp.DatetimeDiff,
             exp.Getbit,
+            exp.Hour,
             exp.TimestampDiff,
             exp.TimeDiff,
             exp.Unicode,
@@ -194,12 +208,14 @@ EXPRESSION_METADATA: ExpressionMetadataType = {
             exp.Concat,
             exp.ConcatWs,
             exp.Chr,
+            exp.CurrentCatalog,
             exp.Dayname,
             exp.DateToDateStr,
             exp.DPipe,
             exp.GroupConcat,
             exp.Initcap,
             exp.Lower,
+            exp.MD5,
             exp.SHA,
             exp.SHA2,
             exp.Substring,
